# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethercat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ethercat_msgs_pb2 as ethercat__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ethercat.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x65thercat.proto\x12\x12Nrmk.IndyFramework\x1a\x13\x65thercat_msgs.proto\x1a\x11\x63ommon_msgs.proto2\xb2\x19\n\x08\x45therCAT\x12P\n\x0fGetMasterStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.MasterStatus\"\x00\x12N\n\x0eGetSlaveStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.SlaveStatus\"\x00\x12V\n\x11GetRxDomainStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EcatDomainStatus\"\x00\x12V\n\x11GetTxDomainStatus\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EcatDomainStatus\"\x00\x12Q\n\rIsSystemReady\x12\x19.Nrmk.IndyFramework.Empty\x1a#.Nrmk.IndyFramework.EcatSystemReady\"\x00\x12I\n\tIsServoOn\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.EcatServoOn\"\x00\x12P\n\x0fGetSlaveTypeNum\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.SlaveTypeNum\"\x00\x12L\n\x12ResetOverflowCount\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12K\n\nSetServoRx\x12 .Nrmk.IndyFramework.ServoRxIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12K\n\nGetServoRx\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1b.Nrmk.IndyFramework.ServoRx\"\x00\x12K\n\nGetServoTx\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1b.Nrmk.IndyFramework.ServoTx\"\x00\x12S\n\x0eSetServoRxKeba\x12$.Nrmk.IndyFramework.ServoRxIndexKeba\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12S\n\x0eGetServoRxKeba\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1f.Nrmk.IndyFramework.ServoRxKeba\"\x00\x12S\n\x0eGetServoTxKeba\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1f.Nrmk.IndyFramework.ServoTxKeba\"\x00\x12I\n\nSetServoOn\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0bSetServoOff\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12V\n\x13GetServoTemperature\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1d.Nrmk.IndyFramework.ServoTemp\"\x00\x12U\n\x11GetServoErrorCode\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x1e.Nrmk.IndyFramework.ServoError\"\x00\x12I\n\nResetServo\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Q\n\x12SetCOREManualBrake\x12\x1e.Nrmk.IndyFramework.ServoBrake\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cSetEndtoolRx\x12\x1d.Nrmk.IndyFramework.EndtoolRx\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cGetEndtoolRx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.EndtoolRx\"\x00\x12J\n\x0cGetEndtoolTx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.EndtoolTx\"\x00\x12X\n\x13GetEndtoolDockingTx\x12\x19.Nrmk.IndyFramework.Empty\x1a$.Nrmk.IndyFramework.EndtoolDockingTx\"\x00\x12J\n\x0cSetIOBoardRx\x12\x1d.Nrmk.IndyFramework.IOBoardRx\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0cGetIOBoardTx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.IOBoardTx\"\x00\x12J\n\x0cGetIOBoardRx\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.IOBoardRx\"\x00\x12L\n\x05GetDI\x12\x1c.Nrmk.IndyFramework.DIOIndex\x1a#.Nrmk.IndyFramework.DIODigitalInput\"\x00\x12M\n\x05GetDO\x12\x1c.Nrmk.IndyFramework.DIOIndex\x1a$.Nrmk.IndyFramework.DIODigitalOutput\"\x00\x12J\n\x05SetDO\x12$.Nrmk.IndyFramework.DIODigitalOutput\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Q\n\x0fGetMaxTorqueSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileVelSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileAccSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12R\n\x10GetProfileDecSDO\x12\x1d.Nrmk.IndyFramework.EcatIndex\x1a\x1d.Nrmk.IndyFramework.SDOIntVal\"\x00\x12N\n\x0fSetMaxTorqueSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileVelSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileAccSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12O\n\x10SetProfileDecSDO\x12\x1e.Nrmk.IndyFramework.ServoParam\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Y\n\x11GetRobotZeroCount\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\".Nrmk.IndyFramework.RobotZeroCount\"\x00\x12T\n\x15SetRobotZeroAsCurrent\x12\x1e.Nrmk.IndyFramework.ServoIndex\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[ethercat__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_ETHERCAT = _descriptor.ServiceDescriptor(
  name='EtherCAT',
  full_name='Nrmk.IndyFramework.EtherCAT',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=79,
  serialized_end=3329,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMasterStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetMasterStatus',
    index=0,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._MASTERSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetSlaveStatus',
    index=1,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._SLAVESTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRxDomainStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetRxDomainStatus',
    index=2,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATDOMAINSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTxDomainStatus',
    full_name='Nrmk.IndyFramework.EtherCAT.GetTxDomainStatus',
    index=3,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATDOMAINSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsSystemReady',
    full_name='Nrmk.IndyFramework.EtherCAT.IsSystemReady',
    index=4,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATSYSTEMREADY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsServoOn',
    full_name='Nrmk.IndyFramework.EtherCAT.IsServoOn',
    index=5,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ECATSERVOON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSlaveTypeNum',
    full_name='Nrmk.IndyFramework.EtherCAT.GetSlaveTypeNum',
    index=6,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._SLAVETYPENUM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetOverflowCount',
    full_name='Nrmk.IndyFramework.EtherCAT.ResetOverflowCount',
    index=7,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoRx',
    index=8,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVORXINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoRx',
    index=9,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVORX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTx',
    index=10,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoRxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoRxKeba',
    index=11,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVORXINDEXKEBA,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoRxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoRxKeba',
    index=12,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVORXKEBA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTxKeba',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTxKeba',
    index=13,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTXKEBA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoOn',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoOn',
    index=14,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoOff',
    full_name='Nrmk.IndyFramework.EtherCAT.SetServoOff',
    index=15,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoTemperature',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoTemperature',
    index=16,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOTEMP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoErrorCode',
    full_name='Nrmk.IndyFramework.EtherCAT.GetServoErrorCode',
    index=17,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._SERVOERROR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetServo',
    full_name='Nrmk.IndyFramework.EtherCAT.ResetServo',
    index=18,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetCOREManualBrake',
    full_name='Nrmk.IndyFramework.EtherCAT.SetCOREManualBrake',
    index=19,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOBRAKE,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndtoolRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetEndtoolRx',
    index=20,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ENDTOOLRX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolRx',
    index=21,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLRX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolTx',
    index=22,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndtoolDockingTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetEndtoolDockingTx',
    index=23,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._ENDTOOLDOCKINGTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetIOBoardRx',
    full_name='Nrmk.IndyFramework.EtherCAT.SetIOBoardRx',
    index=24,
    containing_service=None,
    input_type=ethercat__msgs__pb2._IOBOARDRX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIOBoardTx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetIOBoardTx',
    index=25,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._IOBOARDTX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIOBoardRx',
    full_name='Nrmk.IndyFramework.EtherCAT.GetIOBoardRx',
    index=26,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=ethercat__msgs__pb2._IOBOARDRX,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDI',
    full_name='Nrmk.IndyFramework.EtherCAT.GetDI',
    index=27,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIOINDEX,
    output_type=ethercat__msgs__pb2._DIODIGITALINPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetDO',
    index=28,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIOINDEX,
    output_type=ethercat__msgs__pb2._DIODIGITALOUTPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetDO',
    index=29,
    containing_service=None,
    input_type=ethercat__msgs__pb2._DIODIGITALOUTPUT,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaxTorqueSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetMaxTorqueSDO',
    index=30,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileVelSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileVelSDO',
    index=31,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileAccSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileAccSDO',
    index=32,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProfileDecSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.GetProfileDecSDO',
    index=33,
    containing_service=None,
    input_type=ethercat__msgs__pb2._ECATINDEX,
    output_type=ethercat__msgs__pb2._SDOINTVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetMaxTorqueSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetMaxTorqueSDO',
    index=34,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileVelSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileVelSDO',
    index=35,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileAccSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileAccSDO',
    index=36,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetProfileDecSDO',
    full_name='Nrmk.IndyFramework.EtherCAT.SetProfileDecSDO',
    index=37,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOPARAM,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRobotZeroCount',
    full_name='Nrmk.IndyFramework.EtherCAT.GetRobotZeroCount',
    index=38,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=ethercat__msgs__pb2._ROBOTZEROCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotZeroAsCurrent',
    full_name='Nrmk.IndyFramework.EtherCAT.SetRobotZeroAsCurrent',
    index=39,
    containing_service=None,
    input_type=ethercat__msgs__pb2._SERVOINDEX,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ETHERCAT)

DESCRIPTOR.services_by_name['EtherCAT'] = _ETHERCAT

# @@protoc_insertion_point(module_scope)
