# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import common_msgs_pb2 as common__msgs__pb2
import config_msgs_pb2 as config__msgs__pb2


class ConfigStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRefFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetRefFrame',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.Frame.FromString,
                )
        self.SetRefFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetRefFrame',
                request_serializer=config__msgs__pb2.Frame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetRefFramePlanar = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetRefFramePlanar',
                request_serializer=config__msgs__pb2.PlanarFrame.SerializeToString,
                response_deserializer=config__msgs__pb2.FrameResult.FromString,
                )
        self.SetToolFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetToolFrame',
                request_serializer=config__msgs__pb2.Frame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetSpeedRatio = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSpeedRatio',
                request_serializer=config__msgs__pb2.Ratio.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.SetFTsensorFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetFTsensorFrame',
                request_serializer=config__msgs__pb2.FTsensorFrame.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetFTsensorFrame = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetFTsensorFrame',
                request_serializer=common__msgs__pb2.Response.SerializeToString,
                response_deserializer=config__msgs__pb2.FTsensorFrame.FromString,
                )
        self.SetDIConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetDIConfigList',
                request_serializer=config__msgs__pb2.DIConfigList.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetDIConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetDIConfigList',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.DIConfigList.FromString,
                )
        self.SetDOConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetDOConfigList',
                request_serializer=config__msgs__pb2.DOConfigList.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetDOConfigList = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetDOConfigList',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.DOConfigList.FromString,
                )
        self.SetHomePosition = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetHomePosition',
                request_serializer=config__msgs__pb2.JointPos.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetHomePosition = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetHomePosition',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.JointPos.FromString,
                )
        self.SetAutoServoOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetAutoServoOff',
                request_serializer=config__msgs__pb2.AutoServoOffConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetAutoServoOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetAutoServoOff',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.AutoServoOffConfig.FromString,
                )
        self.SetJointControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetJointControlGain',
                request_serializer=config__msgs__pb2.JointGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetJointControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetJointControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.JointGainSet.FromString,
                )
        self.SetTaskControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetTaskControlGain',
                request_serializer=config__msgs__pb2.TaskGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetTaskControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetTaskControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.TaskGainSet.FromString,
                )
        self.SetImpedanceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetImpedanceControlGain',
                request_serializer=config__msgs__pb2.ImpedanceGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetImpedanceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetImpedanceControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ImpedanceGainSet.FromString,
                )
        self.SetForceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetForceControlGain',
                request_serializer=config__msgs__pb2.ForceGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetForceControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetForceControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ForceGainSet.FromString,
                )
        self.SetTestControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetTestControlGain',
                request_serializer=config__msgs__pb2.TestGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetTestControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetTestControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.TestGainSet.FromString,
                )
        self.SetCustomControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCustomControlGain',
                request_serializer=config__msgs__pb2.CustomGainSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCustomControlGain = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCustomControlGain',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CustomGainSet.FromString,
                )
        self.SetNewControllerTestOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetNewControllerTestOnOff',
                request_serializer=config__msgs__pb2.NewControllerTestState.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetNewControllerTestOnOffState = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetNewControllerTestOnOffState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.NewControllerTestState.FromString,
                )
        self.SetFrictionComp = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetFrictionComp',
                request_serializer=config__msgs__pb2.FrictionCompSet.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetFrictionComp = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetFrictionComp',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.FrictionCompSet.FromString,
                )
        self.SetMountPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetMountPos',
                request_serializer=config__msgs__pb2.MountingAngles.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetMountPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetMountPos',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.MountingAngles.FromString,
                )
        self.SetToolProperty = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetToolProperty',
                request_serializer=config__msgs__pb2.ToolProperties.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetToolProperty = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetToolProperty',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.ToolProperties.FromString,
                )
        self.SetCollSensLevel = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollSensLevel',
                request_serializer=config__msgs__pb2.CollisionSensLevel.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollSensLevel = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollSensLevel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionSensLevel.FromString,
                )
        self.SetCollSensParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollSensParam',
                request_serializer=config__msgs__pb2.CollisionThresholds.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollSensParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollSensParam',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionThresholds.FromString,
                )
        self.SetCollPolicy = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollPolicy',
                request_serializer=config__msgs__pb2.CollisionPolicy.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetCollPolicy = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetCollPolicy',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.CollisionPolicy.FromString,
                )
        self.SetSafetyLimits = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSafetyLimits',
                request_serializer=config__msgs__pb2.SafetyLimits.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetSafetyLimits = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetSafetyLimits',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.SafetyLimits.FromString,
                )
        self.SetSafetyStopConfig = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetSafetyStopConfig',
                request_serializer=config__msgs__pb2.SafetyStopConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )
        self.GetSafetyStopConfig = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/GetSafetyStopConfig',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=config__msgs__pb2.SafetyStopConfig.FromString,
                )
        self.SetCollTuning = channel.unary_unary(
                '/Nrmk.IndyFramework.Config/SetCollTuning',
                request_serializer=config__msgs__pb2.CollTuningConfig.SerializeToString,
                response_deserializer=common__msgs__pb2.Response.FromString,
                )


class ConfigServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetRefFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRefFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRefFramePlanar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSpeedRatio(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFTsensorFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFTsensorFrame(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDIConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDIConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDOConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDOConfigList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetHomePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHomePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAutoServoOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutoServoOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetJointControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJointControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTaskControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetImpedanceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImpedanceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetForceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForceControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTestControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTestControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCustomControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomControlGain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNewControllerTestOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNewControllerTestOnOffState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetFrictionComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrictionComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMountPos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMountPos(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToolProperty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollSensLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollSensLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollSensParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollSensParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCollPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSafetyLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSafetyLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSafetyStopConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSafetyStopConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCollTuning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetRefFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRefFrame,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.Frame.SerializeToString,
            ),
            'SetRefFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRefFrame,
                    request_deserializer=config__msgs__pb2.Frame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetRefFramePlanar': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRefFramePlanar,
                    request_deserializer=config__msgs__pb2.PlanarFrame.FromString,
                    response_serializer=config__msgs__pb2.FrameResult.SerializeToString,
            ),
            'SetToolFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolFrame,
                    request_deserializer=config__msgs__pb2.Frame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetSpeedRatio': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSpeedRatio,
                    request_deserializer=config__msgs__pb2.Ratio.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'SetFTsensorFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFTsensorFrame,
                    request_deserializer=config__msgs__pb2.FTsensorFrame.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetFTsensorFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFTsensorFrame,
                    request_deserializer=common__msgs__pb2.Response.FromString,
                    response_serializer=config__msgs__pb2.FTsensorFrame.SerializeToString,
            ),
            'SetDIConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDIConfigList,
                    request_deserializer=config__msgs__pb2.DIConfigList.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetDIConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDIConfigList,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.DIConfigList.SerializeToString,
            ),
            'SetDOConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDOConfigList,
                    request_deserializer=config__msgs__pb2.DOConfigList.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetDOConfigList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDOConfigList,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.DOConfigList.SerializeToString,
            ),
            'SetHomePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.SetHomePosition,
                    request_deserializer=config__msgs__pb2.JointPos.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetHomePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHomePosition,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.JointPos.SerializeToString,
            ),
            'SetAutoServoOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAutoServoOff,
                    request_deserializer=config__msgs__pb2.AutoServoOffConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetAutoServoOff': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutoServoOff,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.AutoServoOffConfig.SerializeToString,
            ),
            'SetJointControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetJointControlGain,
                    request_deserializer=config__msgs__pb2.JointGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetJointControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJointControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.JointGainSet.SerializeToString,
            ),
            'SetTaskControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTaskControlGain,
                    request_deserializer=config__msgs__pb2.TaskGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetTaskControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.TaskGainSet.SerializeToString,
            ),
            'SetImpedanceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetImpedanceControlGain,
                    request_deserializer=config__msgs__pb2.ImpedanceGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetImpedanceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImpedanceControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ImpedanceGainSet.SerializeToString,
            ),
            'SetForceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetForceControlGain,
                    request_deserializer=config__msgs__pb2.ForceGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetForceControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForceControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ForceGainSet.SerializeToString,
            ),
            'SetTestControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTestControlGain,
                    request_deserializer=config__msgs__pb2.TestGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetTestControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTestControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.TestGainSet.SerializeToString,
            ),
            'SetCustomControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCustomControlGain,
                    request_deserializer=config__msgs__pb2.CustomGainSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCustomControlGain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomControlGain,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CustomGainSet.SerializeToString,
            ),
            'SetNewControllerTestOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNewControllerTestOnOff,
                    request_deserializer=config__msgs__pb2.NewControllerTestState.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetNewControllerTestOnOffState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNewControllerTestOnOffState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.NewControllerTestState.SerializeToString,
            ),
            'SetFrictionComp': grpc.unary_unary_rpc_method_handler(
                    servicer.SetFrictionComp,
                    request_deserializer=config__msgs__pb2.FrictionCompSet.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetFrictionComp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrictionComp,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.FrictionCompSet.SerializeToString,
            ),
            'SetMountPos': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMountPos,
                    request_deserializer=config__msgs__pb2.MountingAngles.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetMountPos': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMountPos,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.MountingAngles.SerializeToString,
            ),
            'SetToolProperty': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolProperty,
                    request_deserializer=config__msgs__pb2.ToolProperties.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetToolProperty': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToolProperty,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.ToolProperties.SerializeToString,
            ),
            'SetCollSensLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollSensLevel,
                    request_deserializer=config__msgs__pb2.CollisionSensLevel.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollSensLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollSensLevel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionSensLevel.SerializeToString,
            ),
            'SetCollSensParam': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollSensParam,
                    request_deserializer=config__msgs__pb2.CollisionThresholds.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollSensParam': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollSensParam,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionThresholds.SerializeToString,
            ),
            'SetCollPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollPolicy,
                    request_deserializer=config__msgs__pb2.CollisionPolicy.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetCollPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCollPolicy,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.CollisionPolicy.SerializeToString,
            ),
            'SetSafetyLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSafetyLimits,
                    request_deserializer=config__msgs__pb2.SafetyLimits.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetSafetyLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSafetyLimits,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.SafetyLimits.SerializeToString,
            ),
            'SetSafetyStopConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSafetyStopConfig,
                    request_deserializer=config__msgs__pb2.SafetyStopConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
            'GetSafetyStopConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSafetyStopConfig,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=config__msgs__pb2.SafetyStopConfig.SerializeToString,
            ),
            'SetCollTuning': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCollTuning,
                    request_deserializer=config__msgs__pb2.CollTuningConfig.FromString,
                    response_serializer=common__msgs__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Nrmk.IndyFramework.Config', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Config(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetRefFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetRefFrame',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.Frame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRefFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetRefFrame',
            config__msgs__pb2.Frame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRefFramePlanar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetRefFramePlanar',
            config__msgs__pb2.PlanarFrame.SerializeToString,
            config__msgs__pb2.FrameResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetToolFrame',
            config__msgs__pb2.Frame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSpeedRatio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSpeedRatio',
            config__msgs__pb2.Ratio.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFTsensorFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetFTsensorFrame',
            config__msgs__pb2.FTsensorFrame.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFTsensorFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetFTsensorFrame',
            common__msgs__pb2.Response.SerializeToString,
            config__msgs__pb2.FTsensorFrame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDIConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetDIConfigList',
            config__msgs__pb2.DIConfigList.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDIConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetDIConfigList',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.DIConfigList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDOConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetDOConfigList',
            config__msgs__pb2.DOConfigList.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDOConfigList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetDOConfigList',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.DOConfigList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetHomePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetHomePosition',
            config__msgs__pb2.JointPos.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHomePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetHomePosition',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.JointPos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAutoServoOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetAutoServoOff',
            config__msgs__pb2.AutoServoOffConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutoServoOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetAutoServoOff',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.AutoServoOffConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetJointControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetJointControlGain',
            config__msgs__pb2.JointGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJointControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetJointControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.JointGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTaskControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetTaskControlGain',
            config__msgs__pb2.TaskGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTaskControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetTaskControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.TaskGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetImpedanceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetImpedanceControlGain',
            config__msgs__pb2.ImpedanceGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImpedanceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetImpedanceControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ImpedanceGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetForceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetForceControlGain',
            config__msgs__pb2.ForceGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForceControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetForceControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ForceGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTestControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetTestControlGain',
            config__msgs__pb2.TestGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTestControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetTestControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.TestGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCustomControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCustomControlGain',
            config__msgs__pb2.CustomGainSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCustomControlGain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCustomControlGain',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CustomGainSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNewControllerTestOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetNewControllerTestOnOff',
            config__msgs__pb2.NewControllerTestState.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNewControllerTestOnOffState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetNewControllerTestOnOffState',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.NewControllerTestState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetFrictionComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetFrictionComp',
            config__msgs__pb2.FrictionCompSet.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFrictionComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetFrictionComp',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.FrictionCompSet.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMountPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetMountPos',
            config__msgs__pb2.MountingAngles.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMountPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetMountPos',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.MountingAngles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetToolProperty',
            config__msgs__pb2.ToolProperties.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToolProperty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetToolProperty',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.ToolProperties.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollSensLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollSensLevel',
            config__msgs__pb2.CollisionSensLevel.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollSensLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollSensLevel',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionSensLevel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollSensParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollSensParam',
            config__msgs__pb2.CollisionThresholds.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollSensParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollSensParam',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionThresholds.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollPolicy',
            config__msgs__pb2.CollisionPolicy.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCollPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetCollPolicy',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.CollisionPolicy.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSafetyLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSafetyLimits',
            config__msgs__pb2.SafetyLimits.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSafetyLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetSafetyLimits',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.SafetyLimits.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSafetyStopConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetSafetyStopConfig',
            config__msgs__pb2.SafetyStopConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSafetyStopConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/GetSafetyStopConfig',
            common__msgs__pb2.Empty.SerializeToString,
            config__msgs__pb2.SafetyStopConfig.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCollTuning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Config/SetCollTuning',
            config__msgs__pb2.CollTuningConfig.SerializeToString,
            common__msgs__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
