# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rtde_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import device_msgs_pb2 as device__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rtde_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0frtde_msgs.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x64\x65vice_msgs.proto\x1a\x11\x63ommon_msgs.proto\"-\n\x0bTestRequest\x12\x0e\n\x06intVal\x18\x01 \x01(\x05\x12\x0e\n\x06strVal\x18\x02 \x01(\t\")\n\x0cTestResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\xeb\x02\n\nMotionData\x12\x31\n\ntraj_state\x18\x01 \x01(\x0e\x32\x1d.Nrmk.IndyFramework.TrajState\x12\x15\n\rtraj_progress\x18\x02 \x01(\x05\x12\x14\n\x0cis_in_motion\x18\x03 \x01(\x08\x12\x19\n\x11is_target_reached\x18\x04 \x01(\x08\x12\x12\n\nis_pausing\x18\x05 \x01(\x08\x12\x13\n\x0bis_stopping\x18\x06 \x01(\x08\x12\x12\n\nhas_motion\x18\x07 \x01(\x08\x12\x13\n\x0bspeed_ratio\x18\x08 \x01(\x05\x12\x11\n\tmotion_id\x18\t \x01(\x05\x12\x17\n\x0fremain_distance\x18\n \x01(\x02\x12\x19\n\x11motion_queue_size\x18\x0b \x01(\r\x12\x19\n\x11\x63ur_traj_progress\x18\x0c \x01(\x05\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9a\x02\n\x0b\x43ontrolData\x12\x15\n\rrunning_hours\x18\x01 \x01(\r\x12\x14\n\x0crunning_mins\x18\x02 \x01(\r\x12\x14\n\x0crunning_secs\x18\x03 \x01(\r\x12-\n\x08op_state\x18\x04 \x01(\x0e\x32\x1b.Nrmk.IndyFramework.OpState\x12\x10\n\x08sim_mode\x18\x05 \x01(\x08\x12\t\n\x01q\x18\n \x03(\x02\x12\x0c\n\x04qdot\x18\x0b \x03(\x02\x12\t\n\x01p\x18\x0c \x03(\x02\x12\x0c\n\x04pdot\x18\r \x03(\x02\x12\x11\n\tref_frame\x18\x14 \x03(\x02\x12\x12\n\ntool_frame\x18\x15 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9f\x02\n\x0c\x43ontrolData2\x12\t\n\x01q\x18\x01 \x03(\x02\x12\x0c\n\x04qdot\x18\x02 \x03(\x02\x12\r\n\x05qddot\x18\x03 \x03(\x02\x12\x0c\n\x04qdes\x18\x04 \x03(\x02\x12\x0f\n\x07qdotdes\x18\x05 \x03(\x02\x12\x10\n\x08qddotdes\x18\x06 \x03(\x02\x12\t\n\x01p\x18\n \x03(\x02\x12\x0c\n\x04pdot\x18\x0b \x03(\x02\x12\r\n\x05pddot\x18\x0c \x03(\x02\x12\x0c\n\x04pdes\x18\r \x03(\x02\x12\x0f\n\x07pdotdes\x18\x0e \x03(\x02\x12\x10\n\x08pddotdes\x18\x0f \x03(\x02\x12\x0b\n\x03tau\x18\x14 \x03(\x02\x12\x0f\n\x07tau_act\x18\x15 \x03(\x02\x12\x0f\n\x07tau_ext\x18\x16 \x03(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xbc\x03\n\x06IOData\x12-\n\x02\x64i\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12-\n\x02\x64o\x18\x02 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\x12,\n\x02\x61i\x18\x03 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12,\n\x02\x61o\x18\x04 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x31\n\x06\x65nd_di\x18\x05 \x03(\x0b\x32!.Nrmk.IndyFramework.EndtoolSignal\x12\x31\n\x06\x65nd_do\x18\x06 \x03(\x0b\x32!.Nrmk.IndyFramework.EndtoolSignal\x12\x30\n\x06\x65nd_ai\x18\x07 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12\x30\n\x06\x65nd_ao\x18\x08 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x9f\x01\n\rViolationData\x12\x16\n\x0eviolation_code\x18\x01 \x01(\x04\x12\x0f\n\x07j_index\x18\x02 \x01(\r\x12\x0e\n\x06i_args\x18\x03 \x03(\x05\x12\x0e\n\x06\x66_args\x18\x04 \x03(\x02\x12\x15\n\rviolation_str\x18\x05 \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xb9\x01\n\tServoData\x12\x14\n\x0cstatus_codes\x18\x01 \x03(\t\x12\x14\n\x0ctemperatures\x18\x02 \x03(\x02\x12\x10\n\x08voltages\x18\x03 \x03(\x02\x12\x10\n\x08\x63urrents\x18\x04 \x03(\x02\x12\x15\n\rservo_actives\x18\n \x03(\x08\x12\x15\n\rbrake_actives\x18\x0b \x03(\x08\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xa6\x02\n\x0bProgramData\x12\x37\n\rprogram_state\x18\x01 \x01(\x0e\x32 .Nrmk.IndyFramework.ProgramState\x12\x0e\n\x06\x63md_id\x18\x02 \x01(\x05\x12\x12\n\nsub_cmd_id\x18\x03 \x01(\x05\x12\x15\n\rrunning_hours\x18\x04 \x01(\r\x12\x14\n\x0crunning_mins\x18\x05 \x01(\r\x12\x14\n\x0crunning_secs\x18\x06 \x01(\r\x12\x14\n\x0cprogram_name\x18\x07 \x01(\t\x12\x15\n\rprogram_alarm\x18\x08 \x01(\t\x12\x1a\n\x12program_annotation\x18\t \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Responseb\x06proto3'
  ,
  dependencies=[device__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])




_TESTREQUEST = _descriptor.Descriptor(
  name='TestRequest',
  full_name='Nrmk.IndyFramework.TestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intVal', full_name='Nrmk.IndyFramework.TestRequest.intVal', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strVal', full_name='Nrmk.IndyFramework.TestRequest.strVal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=122,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='Nrmk.IndyFramework.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Nrmk.IndyFramework.TestResponse.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='Nrmk.IndyFramework.TestResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=165,
)


_MOTIONDATA = _descriptor.Descriptor(
  name='MotionData',
  full_name='Nrmk.IndyFramework.MotionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traj_state', full_name='Nrmk.IndyFramework.MotionData.traj_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traj_progress', full_name='Nrmk.IndyFramework.MotionData.traj_progress', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_motion', full_name='Nrmk.IndyFramework.MotionData.is_in_motion', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_target_reached', full_name='Nrmk.IndyFramework.MotionData.is_target_reached', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_pausing', full_name='Nrmk.IndyFramework.MotionData.is_pausing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_stopping', full_name='Nrmk.IndyFramework.MotionData.is_stopping', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_motion', full_name='Nrmk.IndyFramework.MotionData.has_motion', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_ratio', full_name='Nrmk.IndyFramework.MotionData.speed_ratio', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_id', full_name='Nrmk.IndyFramework.MotionData.motion_id', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remain_distance', full_name='Nrmk.IndyFramework.MotionData.remain_distance', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motion_queue_size', full_name='Nrmk.IndyFramework.MotionData.motion_queue_size', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_traj_progress', full_name='Nrmk.IndyFramework.MotionData.cur_traj_progress', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.MotionData.response', index=12,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=531,
)


_CONTROLDATA = _descriptor.Descriptor(
  name='ControlData',
  full_name='Nrmk.IndyFramework.ControlData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='running_hours', full_name='Nrmk.IndyFramework.ControlData.running_hours', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_mins', full_name='Nrmk.IndyFramework.ControlData.running_mins', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_secs', full_name='Nrmk.IndyFramework.ControlData.running_secs', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='op_state', full_name='Nrmk.IndyFramework.ControlData.op_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sim_mode', full_name='Nrmk.IndyFramework.ControlData.sim_mode', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='q', full_name='Nrmk.IndyFramework.ControlData.q', index=5,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdot', full_name='Nrmk.IndyFramework.ControlData.qdot', index=6,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='Nrmk.IndyFramework.ControlData.p', index=7,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdot', full_name='Nrmk.IndyFramework.ControlData.pdot', index=8,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref_frame', full_name='Nrmk.IndyFramework.ControlData.ref_frame', index=9,
      number=20, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tool_frame', full_name='Nrmk.IndyFramework.ControlData.tool_frame', index=10,
      number=21, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ControlData.response', index=11,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=816,
)


_CONTROLDATA2 = _descriptor.Descriptor(
  name='ControlData2',
  full_name='Nrmk.IndyFramework.ControlData2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='q', full_name='Nrmk.IndyFramework.ControlData2.q', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdot', full_name='Nrmk.IndyFramework.ControlData2.qdot', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qddot', full_name='Nrmk.IndyFramework.ControlData2.qddot', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdes', full_name='Nrmk.IndyFramework.ControlData2.qdes', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qdotdes', full_name='Nrmk.IndyFramework.ControlData2.qdotdes', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qddotdes', full_name='Nrmk.IndyFramework.ControlData2.qddotdes', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p', full_name='Nrmk.IndyFramework.ControlData2.p', index=6,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdot', full_name='Nrmk.IndyFramework.ControlData2.pdot', index=7,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pddot', full_name='Nrmk.IndyFramework.ControlData2.pddot', index=8,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdes', full_name='Nrmk.IndyFramework.ControlData2.pdes', index=9,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdotdes', full_name='Nrmk.IndyFramework.ControlData2.pdotdes', index=10,
      number=14, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pddotdes', full_name='Nrmk.IndyFramework.ControlData2.pddotdes', index=11,
      number=15, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau', full_name='Nrmk.IndyFramework.ControlData2.tau', index=12,
      number=20, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau_act', full_name='Nrmk.IndyFramework.ControlData2.tau_act', index=13,
      number=21, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tau_ext', full_name='Nrmk.IndyFramework.ControlData2.tau_ext', index=14,
      number=22, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ControlData2.response', index=15,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=1106,
)


_IODATA = _descriptor.Descriptor(
  name='IOData',
  full_name='Nrmk.IndyFramework.IOData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di', full_name='Nrmk.IndyFramework.IOData.di', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do', full_name='Nrmk.IndyFramework.IOData.do', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai', full_name='Nrmk.IndyFramework.IOData.ai', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao', full_name='Nrmk.IndyFramework.IOData.ao', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_di', full_name='Nrmk.IndyFramework.IOData.end_di', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_do', full_name='Nrmk.IndyFramework.IOData.end_do', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ai', full_name='Nrmk.IndyFramework.IOData.end_ai', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ao', full_name='Nrmk.IndyFramework.IOData.end_ao', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.IOData.response', index=8,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1553,
)


_VIOLATIONDATA = _descriptor.Descriptor(
  name='ViolationData',
  full_name='Nrmk.IndyFramework.ViolationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='violation_code', full_name='Nrmk.IndyFramework.ViolationData.violation_code', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j_index', full_name='Nrmk.IndyFramework.ViolationData.j_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i_args', full_name='Nrmk.IndyFramework.ViolationData.i_args', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='f_args', full_name='Nrmk.IndyFramework.ViolationData.f_args', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='violation_str', full_name='Nrmk.IndyFramework.ViolationData.violation_str', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ViolationData.response', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1715,
)


_SERVODATA = _descriptor.Descriptor(
  name='ServoData',
  full_name='Nrmk.IndyFramework.ServoData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_codes', full_name='Nrmk.IndyFramework.ServoData.status_codes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperatures', full_name='Nrmk.IndyFramework.ServoData.temperatures', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltages', full_name='Nrmk.IndyFramework.ServoData.voltages', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currents', full_name='Nrmk.IndyFramework.ServoData.currents', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='servo_actives', full_name='Nrmk.IndyFramework.ServoData.servo_actives', index=4,
      number=10, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_actives', full_name='Nrmk.IndyFramework.ServoData.brake_actives', index=5,
      number=11, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ServoData.response', index=6,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1718,
  serialized_end=1903,
)


_PROGRAMDATA = _descriptor.Descriptor(
  name='ProgramData',
  full_name='Nrmk.IndyFramework.ProgramData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='program_state', full_name='Nrmk.IndyFramework.ProgramData.program_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd_id', full_name='Nrmk.IndyFramework.ProgramData.cmd_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_cmd_id', full_name='Nrmk.IndyFramework.ProgramData.sub_cmd_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_hours', full_name='Nrmk.IndyFramework.ProgramData.running_hours', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_mins', full_name='Nrmk.IndyFramework.ProgramData.running_mins', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running_secs', full_name='Nrmk.IndyFramework.ProgramData.running_secs', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_name', full_name='Nrmk.IndyFramework.ProgramData.program_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_alarm', full_name='Nrmk.IndyFramework.ProgramData.program_alarm', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='program_annotation', full_name='Nrmk.IndyFramework.ProgramData.program_annotation', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.ProgramData.response', index=9,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1906,
  serialized_end=2200,
)

_MOTIONDATA.fields_by_name['traj_state'].enum_type = common__msgs__pb2._TRAJSTATE
_MOTIONDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CONTROLDATA.fields_by_name['op_state'].enum_type = common__msgs__pb2._OPSTATE
_CONTROLDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_CONTROLDATA2.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_IODATA.fields_by_name['di'].message_type = device__msgs__pb2._DIGITALSIGNAL
_IODATA.fields_by_name['do'].message_type = device__msgs__pb2._DIGITALSIGNAL
_IODATA.fields_by_name['ai'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['ao'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['end_di'].message_type = device__msgs__pb2._ENDTOOLSIGNAL
_IODATA.fields_by_name['end_do'].message_type = device__msgs__pb2._ENDTOOLSIGNAL
_IODATA.fields_by_name['end_ai'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['end_ao'].message_type = device__msgs__pb2._ANALOGSIGNAL
_IODATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_VIOLATIONDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_SERVODATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_PROGRAMDATA.fields_by_name['program_state'].enum_type = common__msgs__pb2._PROGRAMSTATE
_PROGRAMDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['TestRequest'] = _TESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['MotionData'] = _MOTIONDATA
DESCRIPTOR.message_types_by_name['ControlData'] = _CONTROLDATA
DESCRIPTOR.message_types_by_name['ControlData2'] = _CONTROLDATA2
DESCRIPTOR.message_types_by_name['IOData'] = _IODATA
DESCRIPTOR.message_types_by_name['ViolationData'] = _VIOLATIONDATA
DESCRIPTOR.message_types_by_name['ServoData'] = _SERVODATA
DESCRIPTOR.message_types_by_name['ProgramData'] = _PROGRAMDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUEST,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TestRequest)
  })
_sym_db.RegisterMessage(TestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)

MotionData = _reflection.GeneratedProtocolMessageType('MotionData', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotionData)
  })
_sym_db.RegisterMessage(MotionData)

ControlData = _reflection.GeneratedProtocolMessageType('ControlData', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ControlData)
  })
_sym_db.RegisterMessage(ControlData)

ControlData2 = _reflection.GeneratedProtocolMessageType('ControlData2', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATA2,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ControlData2)
  })
_sym_db.RegisterMessage(ControlData2)

IOData = _reflection.GeneratedProtocolMessageType('IOData', (_message.Message,), {
  'DESCRIPTOR' : _IODATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOData)
  })
_sym_db.RegisterMessage(IOData)

ViolationData = _reflection.GeneratedProtocolMessageType('ViolationData', (_message.Message,), {
  'DESCRIPTOR' : _VIOLATIONDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ViolationData)
  })
_sym_db.RegisterMessage(ViolationData)

ServoData = _reflection.GeneratedProtocolMessageType('ServoData', (_message.Message,), {
  'DESCRIPTOR' : _SERVODATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoData)
  })
_sym_db.RegisterMessage(ServoData)

ProgramData = _reflection.GeneratedProtocolMessageType('ProgramData', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMDATA,
  '__module__' : 'rtde_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ProgramData)
  })
_sym_db.RegisterMessage(ProgramData)


# @@protoc_insertion_point(module_scope)
