# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='device_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x64\x65vice_msgs.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x63ommon_msgs.proto\"&\n\x05Motor\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"&\n\x05Servo\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x08\"Q\n\rDigitalSignal\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .Nrmk.IndyFramework.DigitalState\"O\n\rEndtoolSignal\x12\x0c\n\x04port\x18\x01 \x01(\t\x12\x30\n\x06states\x18\x02 \x03(\x0e\x32 .Nrmk.IndyFramework.EndtoolState\"0\n\x0c\x41nalogSignal\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\r\x12\x0f\n\x07voltage\x18\x02 \x01(\x05\"6\n\tMotorList\x12)\n\x06motors\x18\x01 \x03(\x0b\x32\x19.Nrmk.IndyFramework.Motor\"A\n\x0b\x44igitalList\x12\x32\n\x07signals\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.DigitalSignal\"G\n\x11\x45ndtoolSignalList\x12\x32\n\x07signals\x18\x01 \x03(\x0b\x32!.Nrmk.IndyFramework.EndtoolSignal\"?\n\nAnalogList\x12\x31\n\x07signals\x18\x01 \x03(\x0b\x32 .Nrmk.IndyFramework.AnalogSignal\"\x96\x02\n\nDeviceInfo\x12\x12\n\nnum_joints\x18\x01 \x01(\r\x12\x14\n\x0crobot_serial\x18\x02 \x01(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x02\x12\x17\n\x0fio_board_fw_ver\x18\n \x01(\t\x12\x1a\n\x12\x63ore_board_fw_vers\x18\x0b \x03(\t\x12\x1c\n\x14\x65ndtool_board_fw_ver\x18\x0c \x01(\t\x12\x16\n\x0e\x63ontroller_ver\x18\x14 \x01(\t\x12\x19\n\x11\x63ontroller_detail\x18\x15 \x01(\t\x12\x17\n\x0f\x63ontroller_date\x18\x16 \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\xc7\x01\n\x11\x42rakeControlStyle\x12\x41\n\x05style\x18\x01 \x01(\x0e\x32\x32.Nrmk.IndyFramework.BrakeControlStyle.ControlStyle\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"?\n\x0c\x43ontrolStyle\x12\x0f\n\x0bUNAVAILABLE\x10\x00\x12\x0e\n\nCONCURRENT\x10\x01\x12\x0e\n\nINDIVIDUAL\x10\x02\"~\n\rGetEL5001Data\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\x12\r\n\x05\x64\x65lta\x18\x03 \x01(\x05\x12\x0f\n\x07\x61verage\x18\x04 \x01(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x8d\x01\n\rGetEL5101Data\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\x12\r\n\x05latch\x18\x03 \x01(\x05\x12\r\n\x05\x64\x65lta\x18\x04 \x01(\x05\x12\x0f\n\x07\x61verage\x18\x05 \x01(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"V\n\x0c\x46TSensorType\x12\x16\n\x0e\x66t_sensor_type\x18\x01 \x01(\t\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response\"\x98\x01\n\x0c\x46TSensorData\x12\r\n\x05\x66t_Fx\x18\x01 \x01(\x02\x12\r\n\x05\x66t_Fy\x18\x02 \x01(\x02\x12\r\n\x05\x66t_Fz\x18\x03 \x01(\x02\x12\r\n\x05\x66t_Tx\x18\x04 \x01(\x02\x12\r\n\x05\x66t_Ty\x18\x05 \x01(\x02\x12\r\n\x05\x66t_Tz\x18\x06 \x01(\x02\x12.\n\x08response\x18\x64 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.Response*=\n\x0c\x44igitalState\x12\r\n\tOFF_STATE\x10\x00\x12\x0c\n\x08ON_STATE\x10\x01\x12\x10\n\x0cUNUSED_STATE\x10\x02*b\n\x0c\x45ndtoolState\x12\n\n\x06UNUSED\x10\x00\x12\x0c\n\x08HIGH_PNP\x10\x02\x12\x0c\n\x08HIGH_NPN\x10\x01\x12\x14\n\x07LOW_NPN\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x14\n\x07LOW_PNP\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x62\x06proto3'
  ,
  dependencies=[common__msgs__pb2.DESCRIPTOR,])

_DIGITALSTATE = _descriptor.EnumDescriptor(
  name='DigitalState',
  full_name='Nrmk.IndyFramework.DigitalState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF_STATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_STATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNUSED_STATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1613,
  serialized_end=1674,
)
_sym_db.RegisterEnumDescriptor(_DIGITALSTATE)

DigitalState = enum_type_wrapper.EnumTypeWrapper(_DIGITALSTATE)
_ENDTOOLSTATE = _descriptor.EnumDescriptor(
  name='EndtoolState',
  full_name='Nrmk.IndyFramework.EndtoolState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNUSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_PNP', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_NPN', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW_NPN', index=3, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW_PNP', index=4, number=-2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1676,
  serialized_end=1774,
)
_sym_db.RegisterEnumDescriptor(_ENDTOOLSTATE)

EndtoolState = enum_type_wrapper.EnumTypeWrapper(_ENDTOOLSTATE)
OFF_STATE = 0
ON_STATE = 1
UNUSED_STATE = 2
UNUSED = 0
HIGH_PNP = 2
HIGH_NPN = 1
LOW_NPN = -1
LOW_PNP = -2


_BRAKECONTROLSTYLE_CONTROLSTYLE = _descriptor.EnumDescriptor(
  name='ControlStyle',
  full_name='Nrmk.IndyFramework.BrakeControlStyle.ControlStyle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONCURRENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDIVIDUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1033,
  serialized_end=1096,
)
_sym_db.RegisterEnumDescriptor(_BRAKECONTROLSTYLE_CONTROLSTYLE)


_MOTOR = _descriptor.Descriptor(
  name='Motor',
  full_name='Nrmk.IndyFramework.Motor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='Nrmk.IndyFramework.Motor.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='Nrmk.IndyFramework.Motor.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=98,
)


_SERVO = _descriptor.Descriptor(
  name='Servo',
  full_name='Nrmk.IndyFramework.Servo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='Nrmk.IndyFramework.Servo.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable', full_name='Nrmk.IndyFramework.Servo.enable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=138,
)


_DIGITALSIGNAL = _descriptor.Descriptor(
  name='DigitalSignal',
  full_name='Nrmk.IndyFramework.DigitalSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='Nrmk.IndyFramework.DigitalSignal.address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Nrmk.IndyFramework.DigitalSignal.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=221,
)


_ENDTOOLSIGNAL = _descriptor.Descriptor(
  name='EndtoolSignal',
  full_name='Nrmk.IndyFramework.EndtoolSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='Nrmk.IndyFramework.EndtoolSignal.port', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='Nrmk.IndyFramework.EndtoolSignal.states', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=302,
)


_ANALOGSIGNAL = _descriptor.Descriptor(
  name='AnalogSignal',
  full_name='Nrmk.IndyFramework.AnalogSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='Nrmk.IndyFramework.AnalogSignal.address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='Nrmk.IndyFramework.AnalogSignal.voltage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=352,
)


_MOTORLIST = _descriptor.Descriptor(
  name='MotorList',
  full_name='Nrmk.IndyFramework.MotorList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motors', full_name='Nrmk.IndyFramework.MotorList.motors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=408,
)


_DIGITALLIST = _descriptor.Descriptor(
  name='DigitalList',
  full_name='Nrmk.IndyFramework.DigitalList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='Nrmk.IndyFramework.DigitalList.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=475,
)


_ENDTOOLSIGNALLIST = _descriptor.Descriptor(
  name='EndtoolSignalList',
  full_name='Nrmk.IndyFramework.EndtoolSignalList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='Nrmk.IndyFramework.EndtoolSignalList.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=548,
)


_ANALOGLIST = _descriptor.Descriptor(
  name='AnalogList',
  full_name='Nrmk.IndyFramework.AnalogList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signals', full_name='Nrmk.IndyFramework.AnalogList.signals', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=613,
)


_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='Nrmk.IndyFramework.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_joints', full_name='Nrmk.IndyFramework.DeviceInfo.num_joints', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_serial', full_name='Nrmk.IndyFramework.DeviceInfo.robot_serial', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='Nrmk.IndyFramework.DeviceInfo.payload', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_board_fw_ver', full_name='Nrmk.IndyFramework.DeviceInfo.io_board_fw_ver', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='core_board_fw_vers', full_name='Nrmk.IndyFramework.DeviceInfo.core_board_fw_vers', index=4,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endtool_board_fw_ver', full_name='Nrmk.IndyFramework.DeviceInfo.endtool_board_fw_ver', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_ver', full_name='Nrmk.IndyFramework.DeviceInfo.controller_ver', index=6,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_detail', full_name='Nrmk.IndyFramework.DeviceInfo.controller_detail', index=7,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller_date', full_name='Nrmk.IndyFramework.DeviceInfo.controller_date', index=8,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.DeviceInfo.response', index=9,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=894,
)


_BRAKECONTROLSTYLE = _descriptor.Descriptor(
  name='BrakeControlStyle',
  full_name='Nrmk.IndyFramework.BrakeControlStyle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='style', full_name='Nrmk.IndyFramework.BrakeControlStyle.style', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.BrakeControlStyle.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BRAKECONTROLSTYLE_CONTROLSTYLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=1096,
)


_GETEL5001DATA = _descriptor.Descriptor(
  name='GetEL5001Data',
  full_name='Nrmk.IndyFramework.GetEL5001Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.GetEL5001Data.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.GetEL5001Data.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta', full_name='Nrmk.IndyFramework.GetEL5001Data.delta', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='Nrmk.IndyFramework.GetEL5001Data.average', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.GetEL5001Data.response', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1098,
  serialized_end=1224,
)


_GETEL5101DATA = _descriptor.Descriptor(
  name='GetEL5101Data',
  full_name='Nrmk.IndyFramework.GetEL5101Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.GetEL5101Data.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Nrmk.IndyFramework.GetEL5101Data.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latch', full_name='Nrmk.IndyFramework.GetEL5101Data.latch', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta', full_name='Nrmk.IndyFramework.GetEL5101Data.delta', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average', full_name='Nrmk.IndyFramework.GetEL5101Data.average', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.GetEL5101Data.response', index=5,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1368,
)


_FTSENSORTYPE = _descriptor.Descriptor(
  name='FTSensorType',
  full_name='Nrmk.IndyFramework.FTSensorType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ft_sensor_type', full_name='Nrmk.IndyFramework.FTSensorType.ft_sensor_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.FTSensorType.response', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1456,
)


_FTSENSORDATA = _descriptor.Descriptor(
  name='FTSensorData',
  full_name='Nrmk.IndyFramework.FTSensorData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ft_Fx', full_name='Nrmk.IndyFramework.FTSensorData.ft_Fx', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_Fy', full_name='Nrmk.IndyFramework.FTSensorData.ft_Fy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_Fz', full_name='Nrmk.IndyFramework.FTSensorData.ft_Fz', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_Tx', full_name='Nrmk.IndyFramework.FTSensorData.ft_Tx', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_Ty', full_name='Nrmk.IndyFramework.FTSensorData.ft_Ty', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_Tz', full_name='Nrmk.IndyFramework.FTSensorData.ft_Tz', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='Nrmk.IndyFramework.FTSensorData.response', index=6,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1459,
  serialized_end=1611,
)

_DIGITALSIGNAL.fields_by_name['state'].enum_type = _DIGITALSTATE
_ENDTOOLSIGNAL.fields_by_name['states'].enum_type = _ENDTOOLSTATE
_MOTORLIST.fields_by_name['motors'].message_type = _MOTOR
_DIGITALLIST.fields_by_name['signals'].message_type = _DIGITALSIGNAL
_ENDTOOLSIGNALLIST.fields_by_name['signals'].message_type = _ENDTOOLSIGNAL
_ANALOGLIST.fields_by_name['signals'].message_type = _ANALOGSIGNAL
_DEVICEINFO.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_BRAKECONTROLSTYLE.fields_by_name['style'].enum_type = _BRAKECONTROLSTYLE_CONTROLSTYLE
_BRAKECONTROLSTYLE.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_BRAKECONTROLSTYLE_CONTROLSTYLE.containing_type = _BRAKECONTROLSTYLE
_GETEL5001DATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_GETEL5101DATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_FTSENSORTYPE.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
_FTSENSORDATA.fields_by_name['response'].message_type = common__msgs__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['Motor'] = _MOTOR
DESCRIPTOR.message_types_by_name['Servo'] = _SERVO
DESCRIPTOR.message_types_by_name['DigitalSignal'] = _DIGITALSIGNAL
DESCRIPTOR.message_types_by_name['EndtoolSignal'] = _ENDTOOLSIGNAL
DESCRIPTOR.message_types_by_name['AnalogSignal'] = _ANALOGSIGNAL
DESCRIPTOR.message_types_by_name['MotorList'] = _MOTORLIST
DESCRIPTOR.message_types_by_name['DigitalList'] = _DIGITALLIST
DESCRIPTOR.message_types_by_name['EndtoolSignalList'] = _ENDTOOLSIGNALLIST
DESCRIPTOR.message_types_by_name['AnalogList'] = _ANALOGLIST
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.message_types_by_name['BrakeControlStyle'] = _BRAKECONTROLSTYLE
DESCRIPTOR.message_types_by_name['GetEL5001Data'] = _GETEL5001DATA
DESCRIPTOR.message_types_by_name['GetEL5101Data'] = _GETEL5101DATA
DESCRIPTOR.message_types_by_name['FTSensorType'] = _FTSENSORTYPE
DESCRIPTOR.message_types_by_name['FTSensorData'] = _FTSENSORDATA
DESCRIPTOR.enum_types_by_name['DigitalState'] = _DIGITALSTATE
DESCRIPTOR.enum_types_by_name['EndtoolState'] = _ENDTOOLSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Motor = _reflection.GeneratedProtocolMessageType('Motor', (_message.Message,), {
  'DESCRIPTOR' : _MOTOR,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Motor)
  })
_sym_db.RegisterMessage(Motor)

Servo = _reflection.GeneratedProtocolMessageType('Servo', (_message.Message,), {
  'DESCRIPTOR' : _SERVO,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Servo)
  })
_sym_db.RegisterMessage(Servo)

DigitalSignal = _reflection.GeneratedProtocolMessageType('DigitalSignal', (_message.Message,), {
  'DESCRIPTOR' : _DIGITALSIGNAL,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DigitalSignal)
  })
_sym_db.RegisterMessage(DigitalSignal)

EndtoolSignal = _reflection.GeneratedProtocolMessageType('EndtoolSignal', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLSIGNAL,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolSignal)
  })
_sym_db.RegisterMessage(EndtoolSignal)

AnalogSignal = _reflection.GeneratedProtocolMessageType('AnalogSignal', (_message.Message,), {
  'DESCRIPTOR' : _ANALOGSIGNAL,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.AnalogSignal)
  })
_sym_db.RegisterMessage(AnalogSignal)

MotorList = _reflection.GeneratedProtocolMessageType('MotorList', (_message.Message,), {
  'DESCRIPTOR' : _MOTORLIST,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotorList)
  })
_sym_db.RegisterMessage(MotorList)

DigitalList = _reflection.GeneratedProtocolMessageType('DigitalList', (_message.Message,), {
  'DESCRIPTOR' : _DIGITALLIST,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DigitalList)
  })
_sym_db.RegisterMessage(DigitalList)

EndtoolSignalList = _reflection.GeneratedProtocolMessageType('EndtoolSignalList', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLSIGNALLIST,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolSignalList)
  })
_sym_db.RegisterMessage(EndtoolSignalList)

AnalogList = _reflection.GeneratedProtocolMessageType('AnalogList', (_message.Message,), {
  'DESCRIPTOR' : _ANALOGLIST,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.AnalogList)
  })
_sym_db.RegisterMessage(AnalogList)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEINFO,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DeviceInfo)
  })
_sym_db.RegisterMessage(DeviceInfo)

BrakeControlStyle = _reflection.GeneratedProtocolMessageType('BrakeControlStyle', (_message.Message,), {
  'DESCRIPTOR' : _BRAKECONTROLSTYLE,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BrakeControlStyle)
  })
_sym_db.RegisterMessage(BrakeControlStyle)

GetEL5001Data = _reflection.GeneratedProtocolMessageType('GetEL5001Data', (_message.Message,), {
  'DESCRIPTOR' : _GETEL5001DATA,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GetEL5001Data)
  })
_sym_db.RegisterMessage(GetEL5001Data)

GetEL5101Data = _reflection.GeneratedProtocolMessageType('GetEL5101Data', (_message.Message,), {
  'DESCRIPTOR' : _GETEL5101DATA,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GetEL5101Data)
  })
_sym_db.RegisterMessage(GetEL5101Data)

FTSensorType = _reflection.GeneratedProtocolMessageType('FTSensorType', (_message.Message,), {
  'DESCRIPTOR' : _FTSENSORTYPE,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FTSensorType)
  })
_sym_db.RegisterMessage(FTSensorType)

FTSensorData = _reflection.GeneratedProtocolMessageType('FTSensorData', (_message.Message,), {
  'DESCRIPTOR' : _FTSENSORDATA,
  '__module__' : 'device_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FTSensorData)
  })
_sym_db.RegisterMessage(FTSensorData)


# @@protoc_insertion_point(module_scope)
